summaryrefslogtreecommitdiffstats
path: root/kio/kio/chmodjob.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:35:07 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:35:07 -0600
commit703fb0c89c2eee56a1e613e67a446db9d4287929 (patch)
treedd8c5ca66075cd89c2638a2b48cf78386a9870a7 /kio/kio/chmodjob.h
parent818e7abec3d5d3809b6b77293558678371c16b71 (diff)
downloadtdelibs-703fb0c89c2eee56a1e613e67a446db9d4287929.tar.gz
tdelibs-703fb0c89c2eee56a1e613e67a446db9d4287929.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'kio/kio/chmodjob.h')
-rw-r--r--kio/kio/chmodjob.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kio/kio/chmodjob.h b/kio/kio/chmodjob.h
index fdb873b17..c501add6a 100644
--- a/kio/kio/chmodjob.h
+++ b/kio/kio/chmodjob.h
@@ -28,19 +28,19 @@
#include <kio/job.h>
#include <kfileitem.h>
-namespace KIO {
+namespace TDEIO {
/**
* This job changes permissions on a list of files or directories,
* optionally in a recursive manner.
- * @see KIO::chmod()
+ * @see TDEIO::chmod()
*/
- class KIO_EXPORT ChmodJob : public KIO::Job
+ class KIO_EXPORT ChmodJob : public TDEIO::Job
{
Q_OBJECT
public:
/**
* Create new ChmodJobs using the KIO::chmod() function.
*/
ChmodJob( const KFileItemList & lstItems, int permissions, int mask,
int newOwner, int newGroup,
@@ -51,8 +51,8 @@ namespace KIO {
protected slots:
- virtual void slotResult( KIO::Job *job );
- void slotEntries( KIO::Job * , const KIO::UDSEntryList & );
+ virtual void slotResult( TDEIO::Job *job );
+ void slotEntries( TDEIO::Job * , const TDEIO::UDSEntryList & );
void processList();
private:
@@ -28,19 +28,19 @@
public:
/**
- * Create new ChmodJobs using the KIO::chmod() function.
+ * Create new ChmodJobs using the TDEIO::chmod() function.
*/
ChmodJob( const KFileItemList & lstItems, int permissions, int mask,